<?php

require('../../../wp-config.php');

// Opens a connection to a MySQL server.
$connection = mysqli_connect (DB_HOST, DB_USER, DB_PASSWORD);
if (!$connection) {
	die('Not connected : ' . mysqli_error($connection));
}

// Sets the active MySQL database.
$db_selected = mysqli_select_db($connection, DB_NAME);
if (!$db_selected) {
	die('Can\'t use db : ' . mysqli_error($connection));
}

// Selects all the rows in the markers table.
mysqli_query($connection, 'SET names ' . DB_CHARSET);

$stmt = $connection->prepare("SELECT ff.id, ff.dt, DATE_FORMAT(ff.dt, '%e.%b.%Y') AS dt2, ff.distance, ff.duration, fa1.name AS from_name, fa1.iata AS from_iata, fa1.lat AS lat1, fa1.lng AS lng1, fa2.lat AS lat2, fa2.lng AS lng2, fa2.name AS to_name, fa2.iata AS to_iata, fc.name AS carrier, fp.name AS aircraft FROM " . $table_prefix . "flightlog_flights ff JOIN " . $table_prefix . "flightlog_airports fa1 ON fa1.id=ff.airport_from JOIN " . $table_prefix . "flightlog_airports fa2 ON fa2.id=ff.airport_to JOIN " . $table_prefix . "flightlog_carriers fc ON fc.id=ff.carrier JOIN " . $table_prefix . "flightlog_aircrafts fp ON fp.id=ff.aircraft  WHERE user=? AND dt>=COALESCE(?, dt) AND dt<=COALESCE(?, dt) AND fa1.id=COALESCE(?, fa1.id) AND fa2.id=COALESCE(?, fa2.id) AND fc.id=COALESCE(?, fc.id) AND fp.id=COALESCE(?, fp.id) AND fp.engines=COALESCE(?, fp.engines) AND plane_id=COALESCE(?, plane_id) AND ifr_vfr=COALESCE(?, ifr_vfr) AND day_night=COALESCE(?, day_night) AND approaches=COALESCE(?, approaches) AND landings=COALESCE(?, landings)");

$stmt->bind_param("issiiiiisssii", $_GET['userID'], $_GET['date_from'], $_GET['date_to'], $_GET['from'], $_GET['to'], $_GET['carrier'], $_GET['aircraft'], $_GET['engines'], $_GET['plane_id'], $_GET['ifr_vfr'], $_GET['day_night'], $_GET['approaches'], $_GET['landings']);

$stmt->execute();
$result = $stmt->get_result();

if (!$result) {
	die('Invalid query: ' . mysqli_error($connection));
}

// Creates the Document.
$dom = new DOMDocument('1.0', 'UTF-8');

// Creates the root KML element and appends it to the root document.
$node = $dom->createElementNS('http://earth.google.com/kml/2.1', 'kml');
$parNode = $dom->appendChild($node);

// Creates a KML Document element and append it to the KML element.
$dnode = $dom->createElement('Document');
$docNode = $parNode->appendChild($dnode);

// Creates the two Style elements, one for flightlog and one for bar, and append the elements to the Document element.
$restStyleNode = $dom->createElement('Style');
$restStyleNode->setAttribute('id', 'flightlogStyle');
$restIconstyleNode = $dom->createElement('IconStyle');
$restIconstyleNode->setAttribute('id', 'flightlogIcon');
$restIconNode = $dom->createElement('Icon');
$restHref = $dom->createElement('href', 'http://maps.google.com/mapfiles/kml/pal2/icon63.png');
$restIconNode->appendChild($restHref);
$restIconstyleNode->appendChild($restIconNode);
$restStyleNode->appendChild($restIconstyleNode);
$docNode->appendChild($restStyleNode);

// Iterates through the MySQL results, creating one Placemark for each row.
while ($row = @mysqli_fetch_assoc($result)) {
	// Check FROM-TO and TO-FROM
	if (isset($check_trip[$row['from_iata'].$row['to_iata']])) {
		$check_trip[$row['from_iata'].$row['to_iata']] ++;
		$newNode = $dom->createElement('description', $check_trip[$row['from_iata'].$row['to_iata']] . ' flights, last '.$row['dt2'] . ', ' . $row['carrier'] . ', ' . $row['aircraft']);
		$placeNode[$row['from_iata'].$row['to_iata']]->replaceChild($newNode, $descNode[$row['from_iata'].$row['to_iata']]);
		$descNode[$row['from_iata'].$row['to_iata']] = $newNode;
	}
	else if (isset($check_trip[$row['to_iata'].$row['from_iata']])) {
		$check_trip[$row['to_iata'].$row['from_iata']] ++ ;
		$newNode = $dom->createElement('description', $check_trip[$row['to_iata'].$row['from_iata']] . ' flights, last '.$row['dt2'] . ', ' . $row['carrier'] . ', ' . $row['aircraft']);
		$placeNode[$row['to_iata'].$row['from_iata']]->replaceChild($newNode, $descNode[$row['to_iata'].$row['from_iata']]);
		$descNode[$row['to_iata'].$row['from_iata']] = $newNode;
	}
	else {
		$node = $dom->createElement('Placemark');
		$placeNode[$row['from_iata'].$row['to_iata']] = $docNode->appendChild($node);

		//Create an id attribute and assign it the value of id column
		$placeNode[$row['from_iata'].$row['to_iata']]->setAttribute('id', $row['from_iata'].$row['to_iata']);

		//Create name, description, and address elements and assign them the values of the name, type, and address columns from the results
		$nameNode = $dom->createElement('name', $row['from_name'].' - '.$row['to_name'].' ('.$row['from_iata'].'-'.$row['to_iata'].')');
		$placeNode[$row['from_iata'].$row['to_iata']]->appendChild($nameNode);
		$descNode[$row['from_iata'].$row['to_iata']] = $dom->createElement('description', $row['dt2'] . ', ' . $row['carrier'] . ', ' . $row['aircraft']);
		$placeNode[$row['from_iata'].$row['to_iata']]->appendChild($descNode[$row['from_iata'].$row['to_iata']]);

		//Create a LineString element
		$lineNode = $dom->createElement('LineString');
		$placeNode[$row['from_iata'].$row['to_iata']]->appendChild($lineNode);
		$exnode = $dom->createElement('extrude', '1');
		$lineNode->appendChild($exnode);
		$almodenode =$dom->createElement('altitudeMode','relativeToGround');
		$lineNode->appendChild($almodenode);

		$coorNode = $dom->createElement('coordinates',$row['lng1'].','.$row['lat1'].',100 '.$row['lng2'].','.$row['lat2'].',100 ');
		$lineNode->appendChild($coorNode);

		$check_trip[$row['from_iata'].$row['to_iata']] = 1;
	}
}

$stmt->close();

$kmlOutput = $dom->saveXML();
header('Content-type: application/vnd.google-earth.kml+xml');
echo $kmlOutput;
?>
